@@ -35,7 +35,7 @@ class ProcessMemoryScanner:
         if success:
             return lpBuffer.value
         else:
-            print(f'ERROR: Failed to read memory from address "{converter.int2hex(lpBaseAddress)}"')
+            print(f'ERROR: Failed to read memory from address "{self.converter.int2hex(lpBaseAddress)}"')
             return None
     
     def get_zero_terminated_bytes(self, lpBaseAddress:int, maxSize:int=36):
